@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: objectbase.cc,v 1.6 2004/06/20 03:41:20 daniel Exp $ */
+/* $Id: objectbase.cc,v 1.6.4.1 2006/04/19 11:54:50 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -31,7 +31,7 @@ namespace
 // char array rather than a string literal allows for fast pointer comparison,
 // which is otherwise not guaranteed to work.
 
-const char anonymous_custom_type_name[] = "gtkmm__anonymous_custom_type";
+static const char anonymous_custom_type_name[] = "gtkmm__anonymous_custom_type";
 
 } // anonymous namespace
 
